package net.pricefx.server.dto.calculation;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import net.pricefx.common.api.CalculationResultType;


/**
 * The Gauge widget class implements a graphical speedometer-style gauge for displaying a measurement by means of a needle
 * on a dial. The dial is divided into sectors, each having its own color and value.
 */
public class ResultGauge implements ComplexCalculationResult {

    private static final long serialVersionUID = 1298431956868170847L;

    private BigDecimal value;
	private BigDecimal min;
	private BigDecimal max;
	private List<Map<String,Object>> sectors;
	private String suffix;
	private String prefix;

	public ResultGauge() {
		value = BigDecimal.ZERO;
		sectors = new ArrayList<Map<String,Object>>();
	}

    /**
     * The current value on the dial.
     *
     * @return BigDecimal
     */
	public BigDecimal getValue() {
		return value;
	}


    /**
     * The current value on the dial.
     *
     * @param value the new dial value. Must be between minValue and maxValue. Default value is 0
     */
	public void setValue(BigDecimal value) {
		if(value == null) {
			value = BigDecimal.ZERO;
			return;
		}

		this.value = value;
	}

    /**
     * The minimum dial value.
     *
     * @return BigDecimal
     */
	public BigDecimal getMin() {
		return min;
	}

    /**
     * The minimum dial value.
     *
     * @param minValue the new minimum dial value. Must be at least 1 less than the maximum dial value. If <code>minValue</code> is not at
     * least 1 less than the maximum value, then it is set to <code>maxValue - 1</code>.. Default value is 0
     */
	public void setMin(BigDecimal minValue) {
		this.min = minValue;
	}

    /**
     * The maximum dial value.
     *
     * @return BigDecimal
     */
	public BigDecimal getMax() {
		return max;
	}

    /**
     * The maximum dial value.
     *
     * @param maxValue the new maximum dial value. Must be at least 1 greater than the minimum dial value. If <code>maxValue</code> is not at
     * least 1 greater than the minimum value, then it is set to <code>1 + minValue</code>.. Default value is 100
     */
	public void setMax(BigDecimal maxValue) {
		this.max = maxValue;
	}

    /**
     * Add a GaugeSector contained in this Gauge.
     * If this this property is not specified, the gauge will be created with a
     * default sector filling the gauge.
     *
     *@param upperBound
     *@param color
     */
	public void addSector(BigDecimal upperBound, String color) {
		Map<String,Object> sec = new HashMap<String, Object>();
		sec.put("upperBound", upperBound);
		sec.put("color", color);
		sectors.add(sec);
	}

	public List<Map<String, Object>> getSectors() {
		return sectors;
	}

	public String getSuffix() {
		return suffix;
	}

    /**
     * The label suffix.
     *
     *
     * @param suffix the new label suffix.. Default value is "%"
     */
	public void setSuffix(String suffix) {
		this.suffix = suffix;
	}

    /**
     * The label prefix.
     *
     * @return String
     */
	public String getPrefix() {
		return prefix;
	}

    /**
     * Set the label prefix.
     *
     * @param prefix the new label prefix.. Default value is ""
     */
	public void setPrefix(String prefix) {
		this.prefix = prefix;
	}

	@Override
	public String getResultType() {
		return CalculationResultType.GAUGE.name();
	}

}
